@@ -4,14 +4,14 @@
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="144"/>
+        <location filename="../configothertoolkits.cpp" line="147"/>
         <source>GTK themes</source>
-        <translation type="unfinished"></translation>
+        <translation>GTK témák</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="145"/>
+        <location filename="../configothertoolkits.cpp" line="148"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;p&gt;&apos;%1&apos; felül lett írva. &lt;/p&gt;&lt;p&gt;A régi beállítások másolatát a következő helyen találja: &apos;%2&apos;&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
@@ -29,7 +29,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="36"/>
         <source>Font name:</source>
-        <translation>Betűnév:</translation>
+        <translation>Betűtípus:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="46"/>
@@ -39,7 +39,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="53"/>
         <source>Point size:</source>
-        <translation>Pontméret:</translation>
+        <translation>Méret:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="68"/>
@@ -49,7 +49,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="73"/>
         <source>Bold</source>
-        <translation>Kövér</translation>
+        <translation>Félkövér</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="78"/>
@@ -59,12 +59,12 @@
     <message>
         <location filename="../fontsconfig.ui" line="83"/>
         <source>Bold Italic</source>
-        <translation>Dőlt kövér</translation>
+        <translation>Félkövér dőlt</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="94"/>
         <source>The following settings only affect newly started applications</source>
-        <translation>Ezek a stílusok csak új indítású alkalmazásoknál láthatók</translation>
+        <translation>A következő beállítások csak az újonnan elindított alkalmazásokra vonatkoznak</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="100"/>
@@ -74,7 +74,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="107"/>
         <source>Font hinting style:</source>
-        <translation>Betű javasolt stílus:</translation>
+        <translation>A hinting módja:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="118"/>
@@ -100,7 +100,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="141"/>
         <source>Font hinting</source>
-        <translation>Betű tipp</translation>
+        <translation>Betű hinting</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="148"/>
@@ -110,7 +110,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="155"/>
         <source>Autohint</source>
-        <translation>Automata tipp</translation>
+        <translation>Automatikus hinting</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="172"/>
@@ -171,7 +171,7 @@
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
         <source>Override user-defined wallpaper</source>
-        <translation>Felhasználói háttérképet felülír</translation>
+        <translation>Felhasználói háttérkép felülírása</translation>
     </message>
 </context>
 <context>
@@ -179,30 +179,30 @@
     <message>
         <location filename="../main.cpp" line="58"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>LXQt megjelenésbeállító</translation>
+        <translation>LXQt megjelenés</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="67"/>
+        <location filename="../main.cpp" line="71"/>
         <source>Widget Style</source>
         <translation>Elemtéma</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="72"/>
+        <location filename="../main.cpp" line="79"/>
         <source>Icons Theme</source>
         <translation>Ikontéma</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="77"/>
+        <location filename="../main.cpp" line="88"/>
         <source>LXQt Theme</source>
         <translation>LXQt téma</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="81"/>
+        <location filename="../main.cpp" line="96"/>
         <source>Font</source>
         <translation>Betű</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="87"/>
+        <location filename="../main.cpp" line="106"/>
         <source>Cursor</source>
         <translation>Kurzor</translation>
     </message>
@@ -217,34 +217,36 @@
     <message>
         <location filename="../styleconfig.ui" line="42"/>
         <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
-        <translation type="unfinished"></translation>
+        <translation>Állítsa be a GTK témát (GTK konfigurációs fájlok felül lesznek írva!)</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="62"/>
         <source>GTK 3 Theme</source>
-        <translation type="unfinished"></translation>
+        <translation>GTK 3 téma</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="72"/>
         <source>GTK 2 Theme</source>
-        <translation type="unfinished"></translation>
+        <translation>GTK 2 téma</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="82"/>
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation type="unfinished"></translation>
+        <translation>Az egységes témához válasszon hasonló stílust/témát (ha rendelkezésre áll) az összes listán, vagy válassza a &apos;gtk2&apos; Qt stílust (ha rendelkezésre áll) a GTK téma utánzásához.
+
+Győződjön meg arról, hogy az &apos;xsettingsd&apos; telepítve van, hogy a GTK alkalmazások a menet közben tudjanak témát váltani.</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="99"/>
         <source>Toolbar button style:</source>
-        <translation>Eszközsáv stílus:</translation>
+        <translation>Eszköztárgombok stílusa:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="107"/>
         <source>Only display the icon</source>
-        <translation>Csak ikon</translation>
+        <translation>Csak ikonok</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="112"/>
@@ -254,12 +256,12 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     <message>
         <location filename="../styleconfig.ui" line="117"/>
         <source>The text appears beside the icon</source>
-        <translation>Szöveg az ikon mellett</translation>
+        <translation>Szöveg az ikonok mellett</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="122"/>
         <source>The text appears under the icon</source>
-        <translation>Szöveg az ikon alatt</translation>
+        <translation>Szöveg az ikonok alatt</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="127"/>
@@ -274,7 +276,7 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     <message>
         <location filename="../styleconfig.ui" line="145"/>
         <source>Qt Style</source>
-        <translation type="unfinished"></translation>
+        <translation>Qt stílus</translation>
     </message>
 </context>
 </TS>
