@@ -4,12 +4,12 @@
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="144"/>
+        <location filename="../configothertoolkits.cpp" line="147"/>
         <source>GTK themes</source>
         <translation>Tema GTK</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="145"/>
+        <location filename="../configothertoolkits.cpp" line="148"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
         <translation>&lt;p&gt;&apos;%1&apos; telah ditimpa.&lt;/p&gt;&lt;p&gt;Anda dapat menemukan salinan pengaturan lama Anda di &apos;%2&apos;&lt;/p&gt;</translation>
     </message>
@@ -34,7 +34,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="46"/>
         <source>Style:</source>
-        <translation>Gaya:</translation>
+        <translation>Model:</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="53"/>
@@ -110,7 +110,7 @@
     <message>
         <location filename="../fontsconfig.ui" line="155"/>
         <source>Autohint</source>
-        <translation>Autohint</translation>
+        <translation>Hint otomatis</translation>
     </message>
     <message>
         <location filename="../fontsconfig.ui" line="172"/>
@@ -182,27 +182,27 @@
         <translation>Konfigurasi Penampilan LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="67"/>
+        <location filename="../main.cpp" line="71"/>
         <source>Widget Style</source>
         <translation>Gaya Widget</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="72"/>
+        <location filename="../main.cpp" line="79"/>
         <source>Icons Theme</source>
         <translation>Tema Ikon</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="77"/>
+        <location filename="../main.cpp" line="88"/>
         <source>LXQt Theme</source>
         <translation>Tema LXQt</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="81"/>
+        <location filename="../main.cpp" line="96"/>
         <source>Font</source>
         <translation>Fonta</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="87"/>
+        <location filename="../main.cpp" line="106"/>
         <source>Cursor</source>
         <translation>Kursor</translation>
     </message>
@@ -234,7 +234,8 @@
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation type="unfinished"></translation>
+        <translation>Agar tema tetap sama, dapat memilih style/tema sama (jika tersedia) dari daftar ini, atau memilih style &apos;gtk2&apos; (jika tersedia) untuk meniru tema GTK.
+Pastikan &apos;xsettingsd&apos; terinstal agar aplikasi GTK dapat membantu menerapkan tema langsung.</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="99"/>
