@@ -4,12 +4,12 @@
 <context>
     <name>ConfigOtherToolKits</name>
     <message>
-        <location filename="../configothertoolkits.cpp" line="144"/>
+        <location filename="../configothertoolkits.cpp" line="147"/>
         <source>GTK themes</source>
         <translation>GTK-thema&apos;s</translation>
     </message>
     <message>
-        <location filename="../configothertoolkits.cpp" line="145"/>
+        <location filename="../configothertoolkits.cpp" line="148"/>
         <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
         <translation>&lt;p&gt;&apos;%1&apos; werd overschreven.&lt;/p&gt;&lt;p&gt;U kunt een kopie van uw oude instellingen terugvinden in &apos;%2&apos;&lt;/p&gt;</translation>
     </message>
@@ -182,27 +182,27 @@
         <translation>LXQt-instellingen voor uiterlijk</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="67"/>
+        <location filename="../main.cpp" line="71"/>
         <source>Widget Style</source>
         <translation>Stijl van de bedieningselementen</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="72"/>
+        <location filename="../main.cpp" line="79"/>
         <source>Icons Theme</source>
         <translation>Pictogramthema</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="77"/>
+        <location filename="../main.cpp" line="88"/>
         <source>LXQt Theme</source>
         <translation>LXQt-thema</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="81"/>
+        <location filename="../main.cpp" line="96"/>
         <source>Font</source>
         <translation>Lettertype</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="87"/>
+        <location filename="../main.cpp" line="106"/>
         <source>Cursor</source>
         <translation>Aanwijzer</translation>
     </message>
@@ -234,7 +234,9 @@
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
-        <translation type="unfinished"></translation>
+        <translation>Om uniforme thema&apos;s toe te passen, selecteer of een select gelijkende stijl/thema (indien beschikbaar) voor alle lijsten, of selecteer &apos;gtk2&apos; Qt-stijl (indien beschikbaar) om GTK-thema&apos;s na te bootsen.
+
+Zorg dat &apos;xsettingsd&apos; geïnstalleerd is om GTK-applicaties te helpen om direct thema&apos;s toe te passen.</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="99"/>
