@@ -38,6 +38,7 @@
 #include <XdgDirs>
 #include <LXQt/Settings>
 
+#include <algorithm>
 
 #include "mimetypeviewer.h"
 #include "ui_mimetypeviewer.h"
@@ -65,7 +66,7 @@ void MimetypeViewer::loadAllMimeTypes()
     QMimeDatabase db;
     QList<QMimeType> mimetypes = db.allMimeTypes();
 
-    qSort(mimetypes.begin(), mimetypes.end(), mimeTypeLessThan);
+    std::sort(mimetypes.begin(), mimetypes.end(), mimeTypeLessThan);
     for (const QMimeType &mt : qAsConst(mimetypes)) {
         const QString mimetype = mt.name();
         const int i = mimetype.indexOf(QLatin1Char('/'));
@@ -107,7 +108,7 @@ MimetypeViewer::MimetypeViewer(QWidget *parent)
     connect(widget.chooseApplicationsButton, SIGNAL(clicked()), this, SLOT(chooseApplication()));
     connect(widget.dialogButtonBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(dialogButtonBoxClicked(QAbstractButton*)));
 
-    QString mimeappsListPath(XdgDirs::configHome(true) + "/mimeapps.list");
+    QString mimeappsListPath(XdgDirs::configHome(true) + QStringLiteral("/mimeapps.list"));
     mDefaultsList = new QSettings(mimeappsListPath, XdgDesktopFileCache::desktopFileSettingsFormat(), this);
     mSettingsCache = new LXQt::SettingsCache(mDefaultsList);
     mSettingsCache->loadFromSettings();
@@ -125,7 +126,7 @@ MimetypeViewer::~MimetypeViewer()
 
 void MimetypeViewer::addSearchIcon()
 {
-    QIcon searchIcon = QIcon::fromTheme("system-search");
+    QIcon searchIcon = QIcon::fromTheme(QStringLiteral("system-search"));
     if (searchIcon.isNull())
         return;
 
@@ -194,8 +195,8 @@ void MimetypeViewer::currentMimetypeChanged()
     XdgDesktopFile* defaultApp = XdgDesktopFileCache::getDefaultApp(m_CurrentMime.name());
     if (defaultApp && defaultApp->isValid())
     {
-        QString nonLocalizedName = defaultApp->value("Name").toString();
-        QString localizedName = defaultApp->localizedValue("Name", nonLocalizedName).toString();
+        QString nonLocalizedName = defaultApp->value(QStringLiteral("Name")).toString();
+        QString localizedName = defaultApp->localizedValue(QStringLiteral("Name"), nonLocalizedName).toString();
         QIcon appIcon = defaultApp->icon();
         widget.appIcon->setPixmap(appIcon.pixmap(widget.iconLabel->size()));
         widget.appIcon->show();
@@ -245,7 +246,7 @@ void MimetypeViewer::chooseApplication()
     if (applicationChooser.exec() == QDialog::Accepted && applicationChooser.DefaultApplication())
     {
         QString fileNameNoPath = QFileInfo(applicationChooser.DefaultApplication()->fileName()).fileName();
-        mDefaultsList->beginGroup("Default Applications");
+        mDefaultsList->beginGroup(QStringLiteral("Default Applications"));
         mDefaultsList->setValue(m_CurrentMime.name(), fileNameNoPath);
         mDefaultsList->endGroup();
         currentMimetypeChanged();
