@@ -212,30 +212,35 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="51"/>
+        <location filename="../lxqt-config-input.cpp" line="70"/>
         <source>Keyboard and Mouse Settings</source>
         <translation>Ustawienia myszy i klawiatury</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="56"/>
+        <location filename="../lxqt-config-input.cpp" line="79"/>
         <source>Mouse</source>
         <translation>Mysz</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="61"/>
+        <location filename="../lxqt-config-input.cpp" line="88"/>
         <source>Cursor</source>
         <translation>Kursor</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="64"/>
+        <location filename="../lxqt-config-input.cpp" line="95"/>
         <source>Keyboard</source>
         <translation>Klawiatura</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="68"/>
+        <location filename="../lxqt-config-input.cpp" line="103"/>
         <source>Keyboard Layout</source>
         <translation>Układ klawiatury</translation>
     </message>
+    <message>
+        <location filename="../lxqt-config-input.cpp" line="112"/>
+        <source>Mouse and Touchpad</source>
+        <translation>Mysz i touchpad</translation>
+    </message>
 </context>
 <context>
     <name>SelectKeyboardLayoutDialog</name>
@@ -255,4 +260,62 @@
         <translation>Wariant</translation>
     </message>
 </context>
+<context>
+    <name>TouchpadConfig</name>
+    <message>
+        <location filename="../touchpadconfig.ui" line="14"/>
+        <source>TouchpadConfig </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="20"/>
+        <source>Device:</source>
+        <translation>Urządzenie:</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="30"/>
+        <source>Acceleration speed:</source>
+        <translation>Prędkość przyspieszenia:</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="37"/>
+        <source>Tap to click</source>
+        <translation>Dotknij aby kliknąć</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="44"/>
+        <source>Natural Scrolling</source>
+        <translation>Naturalne przewijanie</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="51"/>
+        <source>Tap and drag</source>
+        <translation>Naciśnij i przeciągnij</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="79"/>
+        <source>Scrolling:</source>
+        <translation>Przewijanie:</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="102"/>
+        <source>&amp;Disabled</source>
+        <translation>&amp;Wyłączone</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="109"/>
+        <source>&amp;Two-Finger</source>
+        <translation>&amp;Dwoma palcami</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="116"/>
+        <source>Ed&amp;ge</source>
+        <translation>Przy &amp;krawędzi</translation>
+    </message>
+    <message>
+        <location filename="../touchpadconfig.ui" line="123"/>
+        <source>B&amp;utton</source>
+        <translation>&amp;Przyciskiem</translation>
+    </message>
+</context>
 </TS>
