@@ -41,6 +41,8 @@
 #include <QDateTime>
 #include <QMessageBox>
 
+#include <algorithm>
+
 const static QString lcLang = QStringLiteral("LANG");
 
 const static QString lcNumeric = QStringLiteral("LC_NUMERIC");
@@ -94,7 +96,7 @@ bool countryLessThan(const QLocale & c1, const QLocale & c2)
 void LocaleConfig::load()
 {
     QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
-    qSort(allLocales.begin(), allLocales.end(), countryLessThan);
+    std::sort(allLocales.begin(), allLocales.end(), countryLessThan);
     for(QComboBox * combo : qAsConst(m_combos))
     {
         initCombo(combo, allLocales);
@@ -147,13 +149,13 @@ void LocaleConfig::addLocaleToCombo(QComboBox *combo, const QLocale &locale)
     // "it_IT")
     // TODO: Properly handle scripts (@foo)
     QString cvalue = locale.name();
-    if (!cvalue.contains('.'))
+    if (!cvalue.contains(QLatin1Char('.')))
     { // explicitely add the encoding, otherwise Qt doesn't accept dead keys and garbles the output as well
-        cvalue.append(QLatin1Char('.') + QTextCodec::codecForLocale()->name());
+        cvalue.append(QLatin1Char('.') + QString::fromUtf8(QTextCodec::codecForLocale()->name()));
     }
 
     QString flagcode;
-    const QStringList split = locale.name().split('_');
+    const QStringList split = locale.name().split(QLatin1Char('_'));
     if (split.count() > 1)
     {
         flagcode = split[1].toLower();
@@ -167,7 +169,7 @@ void LocaleConfig::addLocaleToCombo(QComboBox *combo, const QLocale &locale)
     }
 
     QString itemResult;
-    itemResult = QString("%1 - %2 (%3)")
+    itemResult = QStringLiteral("%1 - %2 (%3)")
                         .arg(clabel)
                         .arg(locale.nativeLanguageName())
                         .arg(locale.name());
@@ -186,18 +188,18 @@ void setCombo(QComboBox *combo, const QString &key)
 
 void LocaleConfig::readConfig()
 {
-    mSettings->beginGroup("Formats");
+    mSettings->beginGroup(QStringLiteral("Formats"));
 
-    bool useDetailed = mSettings->value("useDetailed", false).toBool();
+    bool useDetailed = mSettings->value(QStringLiteral("useDetailed"), false).toBool();
     m_ui->checkDetailed->setChecked(useDetailed);
 
-    setCombo(m_ui->comboGlobal, mSettings->value(lcLang, qgetenv(lcLang.toLatin1())).toString());
+    setCombo(m_ui->comboGlobal, mSettings->value(lcLang, QString::fromLocal8Bit(qgetenv(lcLang.toLatin1().constData()))).toString());
 
-    setCombo(m_ui->comboNumbers, mSettings->value(lcNumeric, qgetenv(lcNumeric.toLatin1())).toString());
-    setCombo(m_ui->comboTime, mSettings->value(lcTime, qgetenv(lcTime.toLatin1())).toString());
-    setCombo(m_ui->comboCollate, mSettings->value(lcCollate, qgetenv(lcCollate.toLatin1())).toString());
-    setCombo(m_ui->comboCurrency, mSettings->value(lcMonetary, qgetenv(lcMonetary.toLatin1())).toString());
-    setCombo(m_ui->comboMeasurement, mSettings->value(lcMeasurement, qgetenv(lcMeasurement.toLatin1())).toString());
+    setCombo(m_ui->comboNumbers, mSettings->value(lcNumeric, QString::fromLocal8Bit(qgetenv(lcNumeric.toLatin1().constData()))).toString());
+    setCombo(m_ui->comboTime, mSettings->value(lcTime, QString::fromLocal8Bit(qgetenv(lcTime.toLatin1().constData()))).toString());
+    setCombo(m_ui->comboCollate, mSettings->value(lcCollate, QString::fromLocal8Bit(qgetenv(lcCollate.toLatin1().constData()))).toString());
+    setCombo(m_ui->comboCurrency, mSettings->value(lcMonetary, QString::fromLocal8Bit(qgetenv(lcMonetary.toLatin1().constData()))).toString());
+    setCombo(m_ui->comboMeasurement, mSettings->value(lcMeasurement, QString::fromLocal8Bit(qgetenv(lcMeasurement.toLatin1().constData()))).toString());
 
     updateEnabled();
 
@@ -206,7 +208,7 @@ void LocaleConfig::readConfig()
 
 void LocaleConfig::writeConfig()
 {
-    mSettings->beginGroup("Formats");
+    mSettings->beginGroup(QStringLiteral("Formats"));
 
     // global ends up empty here when OK button is clicked from kcmshell5,
     // apparently the data in the combo is gone by the time save() is called.
@@ -223,7 +225,7 @@ void LocaleConfig::writeConfig()
     if (!m_ui->checkDetailed->isChecked())
     {
         // Global setting, clean up config
-        mSettings->remove("useDetailed");
+        mSettings->remove(QStringLiteral("useDetailed"));
         if (global.isEmpty())
         {
             mSettings->remove(lcLang);
@@ -242,7 +244,7 @@ void LocaleConfig::writeConfig()
     else
     {
         // Save detailed settings
-        mSettings->setValue("useDetailed", true);
+        mSettings->setValue(QStringLiteral("useDetailed"), true);
 
         if (global.isEmpty())
         {
@@ -328,13 +330,13 @@ void LocaleConfig::saveSettings()
 
 void LocaleConfig::writeExports()
 {
-    sSettings->beginGroup("Environment");
-    mSettings->beginGroup("Formats");
+    sSettings->beginGroup(QStringLiteral("Environment"));
+    mSettings->beginGroup(QStringLiteral("Formats"));
     if (!mSettings->value(lcLang).toString().isNull())
     {
         sSettings->setValue(lcLang, mSettings->value(lcLang).toString());
 
-        if (mSettings->value("useDetailed").toBool())
+        if (mSettings->value(QStringLiteral("useDetailed")).toBool())
         {
             if (!mSettings->value(lcNumeric).toString().isNull())
             {
@@ -376,12 +378,12 @@ void LocaleConfig::defaults()
     m_ui->checkDetailed->setChecked(false);
 
     // restore user defaults from env vars
-    setCombo(m_ui->comboGlobal, qgetenv(lcLang.toLatin1()));
-    setCombo(m_ui->comboNumbers, qgetenv(lcNumeric.toLatin1()));
-    setCombo(m_ui->comboTime, qgetenv(lcTime.toLatin1()));
-    setCombo(m_ui->comboCollate, qgetenv(lcCollate.toLatin1()));
-    setCombo(m_ui->comboCurrency, qgetenv(lcMonetary.toLatin1()));
-    setCombo(m_ui->comboMeasurement, qgetenv(lcMeasurement.toLatin1()));
+    setCombo(m_ui->comboGlobal, QString::fromLocal8Bit(qgetenv(lcLang.toLatin1().constData())));
+    setCombo(m_ui->comboNumbers, QString::fromLocal8Bit(qgetenv(lcNumeric.toLatin1().constData())));
+    setCombo(m_ui->comboTime, QString::fromLocal8Bit(qgetenv(lcTime.toLatin1().constData())));
+    setCombo(m_ui->comboCollate, QString::fromLocal8Bit(qgetenv(lcCollate.toLatin1().constData())));
+    setCombo(m_ui->comboCurrency, QString::fromLocal8Bit(qgetenv(lcMonetary.toLatin1().constData())));
+    setCombo(m_ui->comboMeasurement, QString::fromLocal8Bit(qgetenv(lcMeasurement.toLatin1().constData())));
 
     updateEnabled();
 }
