@@ -29,7 +29,7 @@ Q_DECLARE_METATYPE(MonitorSavedSettings)
 
 
 ManageSavedSettings::ManageSavedSettings(LXQt::Settings * applicationSettings,  KScreen::ConfigPtr config, QWidget * parent):
-QDialog(parent)
+    QDialog(parent)
 {
 
     this->applicationSettings = applicationSettings;
@@ -50,34 +50,32 @@ void ManageSavedSettings::showSelectedConfig(QListWidgetItem * item)
 {
     MonitorSavedSettings o = item->data(Qt::UserRole).value<MonitorSavedSettings>();
     QString text;
-    for(int i=0; i < o.monitors.size(); i++)
-    {
+    for(int i=0; i < o.monitors.size(); i++) {
         MonitorSettings setting = o.monitors[i];
         if(! setting.connected )
             continue;
-        text += QString("<b>%1:</b><br/>").arg(setting.name);
-        text += QString("&nbsp;Mode: %1x%2<br/>").arg(setting.currentModeWidth).arg(setting.currentModeHeight);
-        text += QString("&nbsp;Rate: %1 Hz<br/>").arg(setting.currentModeRate);
-        switch(setting.rotation)
-        {
-            case KScreen::Output::Rotation::None:
-                text += QString("&nbsp;Rotation: %1<br/>").arg(tr("None"));
-                break;
-            case KScreen::Output::Rotation::Left:
-                text += QString("&nbsp;Rotation: %1<br/>").arg(tr("Left"));
-                break;
-            case KScreen::Output::Rotation::Inverted:
-                text += QString("&nbsp;Rotation: %1<br/>").arg(tr("Inverted"));
-                break;
-            case KScreen::Output::Rotation::Right:
-                text += QString("&nbsp;Rotation: %1<br/>").arg(tr("Right"));
-                break;
+        text += QStringLiteral("<b>%1:</b><br/>").arg(setting.name);
+        text += QStringLiteral("&nbsp;Mode: %1x%2<br/>").arg(setting.currentModeWidth).arg(setting.currentModeHeight);
+        text += QStringLiteral("&nbsp;Rate: %1 Hz<br/>").arg(setting.currentModeRate);
+        switch(setting.rotation) {
+        case KScreen::Output::Rotation::None:
+            text += QStringLiteral("&nbsp;Rotation: %1<br/>").arg(tr("None"));
+            break;
+        case KScreen::Output::Rotation::Left:
+            text += QStringLiteral("&nbsp;Rotation: %1<br/>").arg(tr("Left"));
+            break;
+        case KScreen::Output::Rotation::Inverted:
+            text += QStringLiteral("&nbsp;Rotation: %1<br/>").arg(tr("Inverted"));
+            break;
+        case KScreen::Output::Rotation::Right:
+            text += QStringLiteral("&nbsp;Rotation: %1<br/>").arg(tr("Right"));
+            break;
         }
-        text += QString("&nbsp;Position: %1x%2<br/>").arg(setting.xPos).arg(setting.yPos);
-        text += QString("&nbsp;Primary: %1<br/>").arg(setting.primary?tr("True"):tr("False"));
-        text += QString("&nbsp;Enabled: %1<br/>").arg(setting.enabled?tr("True"):tr("False"));
+        text += QStringLiteral("&nbsp;Position: %1x%2<br/>").arg(setting.xPos).arg(setting.yPos);
+        text += QStringLiteral("&nbsp;Primary: %1<br/>").arg(setting.primary?tr("True"):tr("False"));
+        text += QStringLiteral("&nbsp;Enabled: %1<br/>").arg(setting.enabled?tr("True"):tr("False"));
     }
-    text += "<br/>";
+    text += QLatin1String("<br/>");
     ui.selectedSettingsTextEdit->setText(text);
     ui.applyPushButton->setEnabled(isHardwareCompatible(o));
 }
@@ -86,11 +84,9 @@ void ManageSavedSettings::showSelectedConfig(QListWidgetItem * item)
 bool ManageSavedSettings::isHardwareCompatible(const MonitorSavedSettings &settings)
 {
     KScreen::OutputList outputs = config->outputs();
-    for (const KScreen::OutputPtr &output : outputs)
-    {
+    for (const KScreen::OutputPtr &output : outputs) {
         bool ok = false;
-        for (int i=0; i < settings.monitors.size(); i++)
-        {
+        for (int i=0; i < settings.monitors.size(); i++) {
             MonitorSettings o = settings.monitors[i];
             if(o.name != output->name())
                 continue;
@@ -109,13 +105,13 @@ bool ManageSavedSettings::isHardwareCompatible(const MonitorSavedSettings &setti
 
 void ManageSavedSettings::onDeleteItem()
 {
-    if (ui.allConfigs->currentItem() == NULL)
+    if (ui.allConfigs->currentItem() == nullptr)
         return;
     MonitorSavedSettings obj = ui.allConfigs->currentItem()->data(Qt::UserRole).value<MonitorSavedSettings>();
 
-    LXQt::Settings settings("lxqt-config-monitor");
+    LXQt::Settings settings(QStringLiteral("lxqt-config-monitor"));
     QList<MonitorSavedSettings> monitors;
-    settings.beginGroup("SavedConfigs");
+    settings.beginGroup(QStringLiteral("SavedConfigs"));
     loadMonitorSettings(settings, monitors);
     for (int i = 0; i < monitors.size(); i++) {
         MonitorSavedSettings o = monitors[i];
@@ -133,19 +129,19 @@ void ManageSavedSettings::onDeleteItem()
 
 void ManageSavedSettings::onRenameItem()
 {
-    if (ui.allConfigs->currentItem() == NULL)
+    if (ui.allConfigs->currentItem() == nullptr)
         return;
     MonitorSavedSettings obj = ui.allConfigs->currentItem()->data(Qt::UserRole).value<MonitorSavedSettings>();
     bool ok;
     QString configName = QInputDialog::getText(this, tr("Name"), tr("Name:"),
-                                               QLineEdit::Normal,
-                                               obj.name, &ok);
+                         QLineEdit::Normal,
+                         obj.name, &ok);
     if (!ok || configName.isEmpty())
         return;
 
-    LXQt::Settings settings("lxqt-config-monitor");
+    LXQt::Settings settings(QStringLiteral("lxqt-config-monitor"));
     QList<MonitorSavedSettings> monitors;
-    settings.beginGroup("SavedConfigs");
+    settings.beginGroup(QStringLiteral("SavedConfigs"));
     loadMonitorSettings(settings, monitors);
     for (int i = 0; i < monitors.size(); i++) {
         MonitorSavedSettings o = monitors[i];
@@ -165,7 +161,7 @@ void ManageSavedSettings::onRenameItem()
 
 void ManageSavedSettings::onApplyItem()
 {
-    if (ui.allConfigs->currentItem() == NULL)
+    if (ui.allConfigs->currentItem() == nullptr)
         return;
     MonitorSavedSettings settings = ui.allConfigs->currentItem()->data(Qt::UserRole).value<MonitorSavedSettings>();
     applySettings(config, settings.monitors);
@@ -177,13 +173,13 @@ void ManageSavedSettings::loadSettings()
 {
     ui.allConfigs->clear();
     //ui.hardwareCompatibleConfigs->clear();
-    LXQt::Settings settings("lxqt-config-monitor");
+    LXQt::Settings settings(QStringLiteral("lxqt-config-monitor"));
     QList<MonitorSavedSettings> monitors;
-    settings.beginGroup("SavedConfigs");
+    settings.beginGroup(QStringLiteral("SavedConfigs"));
     loadMonitorSettings(settings, monitors);
     settings.endGroup();
     for(const MonitorSavedSettings& o : qAsConst(monitors)) {
-        QListWidgetItem *item = new QListWidgetItem(o.name+" - "+o.date, ui.allConfigs);
+        QListWidgetItem *item = new QListWidgetItem(o.name+QStringLiteral(" - ")+o.date, ui.allConfigs);
         QVariant var;
         var.setValue(o);
         item->setData(Qt::UserRole, var);
