@@ -36,14 +36,14 @@ class MonitorPictureDialog : public QDialog
     Q_OBJECT
 
 public:
-    MonitorPictureDialog(KScreen::ConfigPtr config, QWidget * parent = 0, Qt::WindowFlags f = 0);
+    MonitorPictureDialog(KScreen::ConfigPtr config, QWidget * parent = nullptr, Qt::WindowFlags f = 0);
     void setScene(QList<MonitorWidget*> monitors);
     void updateMonitorWidgets(QString primaryMonitor);
     void moveMonitorPictureToNearest(MonitorPicture* monitorPicture);
     void updateScene();
 
 protected:
-    virtual void showEvent(QShowEvent * event);
+    void showEvent(QShowEvent * event) override;
 
 private:
     Ui::MonitorPictureDialog ui;
@@ -75,8 +75,8 @@ private:
 
 
 protected:
-    QVariant itemChange(GraphicsItemChange change, const QVariant & value);
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
+    QVariant itemChange(GraphicsItemChange change, const QVariant & value) override;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent * event) override;
 };
 
 class MonitorPictureProxy: public QObject
