@@ -30,11 +30,11 @@ class TimeoutDialog : public QDialog
     Q_OBJECT
 
 public:
-    TimeoutDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);
-    virtual ~TimeoutDialog();
+    TimeoutDialog(QWidget* parent = nullptr, Qt::WindowFlags f = 0);
+    ~TimeoutDialog() override;
 
 protected:
-    virtual void showEvent(QShowEvent* e);
+    void showEvent(QShowEvent* e) override;
 
 private Q_SLOTS:
     void onTimeout();
