@@ -34,7 +34,7 @@
     <message>
         <location filename="../managesavedsettings.ui" line="14"/>
         <source>Monitor Settings</source>
-        <translation>Monitor beállítás</translation>
+        <translation>Monitor beállítások</translation>
     </message>
     <message>
         <location filename="../managesavedsettings.ui" line="27"/>
@@ -44,12 +44,12 @@
     <message>
         <location filename="../managesavedsettings.ui" line="38"/>
         <source>Rename</source>
-        <translation>Átnevez</translation>
+        <translation>Átnevezés</translation>
     </message>
     <message>
         <location filename="../managesavedsettings.ui" line="45"/>
         <source>Delete</source>
-        <translation>Töröl</translation>
+        <translation>Törlés</translation>
     </message>
     <message>
         <location filename="../managesavedsettings.ui" line="52"/>
@@ -59,7 +59,7 @@
     <message>
         <location filename="../managesavedsettings.cpp" line="64"/>
         <source>None</source>
-        <translation>Semmi</translation>
+        <translation>Nincs</translation>
     </message>
     <message>
         <location filename="../managesavedsettings.cpp" line="67"/>
@@ -112,7 +112,7 @@
     <message>
         <location filename="../monitorsettingsdialog.ui" line="14"/>
         <source>Monitor Settings</source>
-        <translation>Monitor beállítás</translation>
+        <translation>Monitor beállítások</translation>
     </message>
     <message>
         <location filename="../monitorsettingsdialog.ui" line="70"/>
@@ -127,7 +127,7 @@
     <message>
         <location filename="../monitorsettingsdialog.cpp" line="115"/>
         <source>Set position</source>
-        <translation>Pozícionálás</translation>
+        <translation>Pozicionálás</translation>
     </message>
     <message>
         <location filename="../monitorsettingsdialog.cpp" line="247"/>
@@ -170,7 +170,7 @@
     <message>
         <location filename="../monitorwidget.ui" line="103"/>
         <source>This screen extends another display</source>
-        <translation>Kiterjesztődik más megjelenítőre is</translation>
+        <translation>Kiterjesztés más megjelenítőre is</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="125"/>
@@ -180,7 +180,7 @@
     <message>
         <location filename="../monitorwidget.ui" line="146"/>
         <source>Refresh rate:</source>
-        <translation>Frissítési ütem:</translation>
+        <translation>Frissítési gyakoriság:</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="153"/>
@@ -190,12 +190,12 @@
     <message>
         <location filename="../monitorwidget.ui" line="176"/>
         <source>Info</source>
-        <translation>Infó</translation>
+        <translation>Információ</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="182"/>
         <source>Display information</source>
-        <translation>Megjelenítő infó</translation>
+        <translation>Megjelenítő információ</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="135"/>
@@ -215,7 +215,7 @@
         <location filename="../monitorwidget.cpp" line="137"/>
         <source>Serial: %1
 </source>
-        <translation>Sorszám: %1
+        <translation>Sorozatszám: %1
 </translation>
     </message>
     <message>
@@ -236,12 +236,13 @@
         <location filename="../monitorwidget.cpp" line="140"/>
         <source>EISA device ID: %1
 </source>
-        <translation></translation>
+        <translation>EISA eszköz ID: %1
+</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="161"/>
         <source>None</source>
-        <translation>semmi</translation>
+        <translation>Nincs</translation>
     </message>
     <message>
         <location filename="../monitorwidget.cpp" line="162"/>
@@ -277,12 +278,12 @@
     <message>
         <location filename="../savesettings.cpp" line="82"/>
         <source>Name</source>
-        <translation type="unfinished">Név</translation>
+        <translation>Név</translation>
     </message>
     <message>
         <location filename="../savesettings.cpp" line="82"/>
         <source>Name:</source>
-        <translation type="unfinished">Név:</translation>
+        <translation>Név:</translation>
     </message>
 </context>
 <context>
@@ -290,19 +291,20 @@
     <message>
         <location filename="../timeoutdialog.ui" line="14"/>
         <source>Settings are changed</source>
-        <translation>A beállítások változtak</translation>
+        <translation>A beállítások megváltoztak</translation>
     </message>
     <message>
         <location filename="../timeoutdialog.ui" line="46"/>
         <source>Are the current settings OK for you?</source>
-        <translation>Jók a beállítások?</translation>
+        <translation>Megfelelőek a beállítások?</translation>
     </message>
     <message numerus="yes">
         <location filename="../timeoutdialog.cpp" line="65"/>
         <source>%n second(s) remaining</source>
         <translatorcomment>%n másodperc van hátra</translatorcomment>
         <translation>
-            <numerusform></numerusform>
+            <numerusform>%n másodperc van hátra</numerusform>
+            <numerusform>%n másodperc van hátra</numerusform>
         </translation>
     </message>
 </context>
